<?php

namespace Drupal\binary_language_switcher\Plugin\Block;

use Drupal\language\Plugin\Block\LanguageBlock;
use Drupal\Core\Url;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a 'Language switcher' block.
 *
 * @Block(
 *   id = "binary_language_switcher",
 *   admin_label = @Translation("Binary Language Switcher"),
 *   category = @Translation("Multilingual")
 * )
 */
class BinaryLanguageBlock extends LanguageBlock {

  /**
   * {@inheritdoc}
   */
  public function build() {
    $config = $this->getConfiguration();

    $build = [];
    $route_name = $this->pathMatcher->isFrontPage() ? '<front>' : '<current>';
    $type = $this->getDerivativeId();
    $links = $this->languageManager->getLanguageSwitchLinks($type, Url::fromRoute($route_name));

    if ($config['binary_language_switcher_invert']) {
      $keys = array_keys($links->links);
      $temp = $links->links[$keys[0]]['title'];
      $links->links[$keys[0]]['title'] = $links->links[$keys[1]]['title'];
      $links->links[$keys[1]]['title'] = $temp;
    }

    if (isset($links->links)) {
      $build = [
        '#prefix' => $config['binary_language_switcher_prefix'],
        '#theme' => 'links__language_block',
        '#links' => $links->links,
        '#attributes' => [
          'class' => [
            "binary-language-switcher",
            "language-switcher-{$links->method_id}",
          ],
        ],
        '#attached' => [
          'library' => ['binary_language_switcher/binary_language_switcher'],
        ],
        '#set_active_class' => TRUE,
      ];
    }

    return $build;
  }

  /**
   * {@inheritdoc}
   */
  public function blockForm($form, FormStateInterface $form_state) {
    $form = parent::blockForm($form, $form_state);

    $config = $this->getConfiguration();

    $form['binary_language_switcher_prefix'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Prefix Text'),
      '#description' => $this->t('Text to be displayed before the language link.'),
      '#default_value' => isset($config['binary_language_switcher_prefix']) ? $config['binary_language_switcher_prefix'] : $this->t('Switch to'),
    ];

    $form['binary_language_switcher_invert'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Inverse Mode'),
      '#description' => $this->t('Show active language instead of next language.'),
      '#default_value' => isset($config['binary_language_switcher_invert']) ? $config['binary_language_switcher_invert'] : '',
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function blockSubmit($form, FormStateInterface $form_state) {
    parent::blockSubmit($form, $form_state);
    $values = $form_state->getValues();
    $this->configuration['binary_language_switcher_prefix'] = $values['binary_language_switcher_prefix'];
    $this->configuration['binary_language_switcher_invert'] = $values['binary_language_switcher_invert'];

  }

}
